import type { FC } from 'react';

import type { IconName, IconSize } from '@proton/components/components';
import { Icon } from '@proton/components/components';
import { VaultColor } from '@proton/pass/types/protobuf/vault-v1';
import clsx from '@proton/utils/clsx';

import { VAULT_COLOR_MAP } from './constants';

import './VaultTag.scss';

type Props = {
    title: string;
    shared?: boolean;
    icon: IconName;
    color?: VaultColor;
    count?: number;
    iconSize?: IconSize;
};

export const VaultTag: FC<Props> = ({ title, shared = false, icon, color, count, iconSize = 3 }) => {
    return (
        <div
            className={clsx(
                'pass-vault-tag flex items-center text-sm gap-x-2 flex-nowrap lh100',
                shared && 'pass-vault-tag--shared'
            )}
            style={shared ? { '--vault-icon-color': VAULT_COLOR_MAP[color ?? VaultColor.COLOR1] } : undefined}
        >
            {<Icon className="shrink-0" name={icon} size={iconSize} />}
            <span className="text-ellipsis">{title}</span>
            {count !== undefined && count > 1 && <span className="shrink-0">• {count}</span>}
        </div>
    );
};
